##
# This file is part of WhatWeb and may be subject to
# redistribution and commercial restrictions. Please see the WhatWeb
# web site for more information on licensing and terms of use.
# http://www.morningstarsecurity.com/research/whatweb
##
Plugin.define "Commerce-Builder" do
author "Brendan Coles <bcoles@gmail.com>" # 2011-06-01
version "0.1"
description "Internet Factory's Commerce Builder web server [Discontinued] - Homepage: http://www.ifact.com/"

# ShodanHQ results as at 2011-06-01 #
# 32 for commerce-builder



# Passive #
def passive
	m=[]

	# Version Detection # HTTP Server Header
	m << { :version=>@headers["server"].scan(/^Commerce-Builder\/([^\s]+)/) } if @headers["server"] =~ /^Commerce-Builder\/([^\s]+)/

	# Return passive matches
	m
end

end

